#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['ims_client']

package_data = \
{'': ['*']}

install_requires = \
['loguru', 'tenacity']

extras_require = \
{'dev': ['pytest-watch', 'tomlkit', 'black'], 'test': ['pytest', 'pytest-cov']}

setup(name='ims_client',
      version='0.1.1',
      description='Simple python client for the capspire IMS Server',
      author='James Vogel',
      author_email='jim.m.vogel@gmail.com',
      url=None,
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      python_requires='>=3.5',
     )
